==> foundation-ui-components-1.25.0.tgz: package/src/common/banner/NsBanner.stories.tsx <==
/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsBanner.stories.tsx
 * @description NsBanner component.
 */

import React from 'react';
import type { StoryObj, Meta } from '@storybook/react';
import { NsBanner, NsTypography, NsButton } from '../';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';

type ComponentType = typeof NsBanner;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Data Display/NsBanner',
    component: NsBanner,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text', // use the text control to edit children prop
        },
    },
    args: {
        imageUrl: 'https://media.nuskin.com/m/e2f6d26058b2e7d/webimage-us-collagen-strawberry-hompage-banner.png',
        altText: 'NsBanner',
        alignment: 'center',
        justify: 'start',
        children: (
            <div>
                <NsTypography className="w-80" variant="h1" colorOverride="#000000">
                    Limited time offers on LumiSpa iO cleansers and bundles!
                </NsTypography>
                <NsTypography variant="body-m" className="my-5" colorOverride="#000000">
                    Learn more about what I do and how I can help you
                </NsTypography>
                <NsButton variant="contained">Contact me</NsButton>
            </div>
        ),
    },
} as MetaStory;

export const DefaultNsBanner: Story = {};

==> foundation-ui-components-1.30.1.tgz: package/src/common/banner/NsBanner.stories.tsx <==
/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsBanner.stories.tsx
 * @description NsBanner component.
 */

import React, { ReactElement } from 'react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import type { Meta, StoryObj } from '@storybook/react';

import { NsBanner, NsButton, NsTypography } from '../';
import { ImageData1 } from '../card/fixtures/ImageData1';

type ComponentType = typeof NsBanner;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Data Display/NsBanner',
    component: NsBanner,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text', // use the text control to edit children prop
        },
    },
    args: {
        image: ImageData1,
        altText: 'NsBanner',
        alignment: 'center',
        justify: 'start',
        children: (
            <div>
                <NsTypography className="w-80" variant="h1" colorOverride="#000000">
                    Limited time offers on LumiSpa iO cleansers and bundles!
                </NsTypography>
                <NsTypography variant="body-m" className="my-5" colorOverride="#000000">
                    Learn more about what I do and how I can help you
                </NsTypography>
                <NsButton variant="contained">Contact me</NsButton>
            </div>
        ) as ReactElement,
    },
} as MetaStory;

export const DefaultNsBanner: Story = {};
